@@ -33,7 +33,6 @@ import glob
 import multiprocessing as mp
 import os
 import re
-import sys
 
 import numpy as np
 
@@ -44,7 +43,7 @@ WARN = None
 try:
     import conduit
     import conduit.relay.io
-except:
+except ModuleNotFoundError:
     WARN = "\nWARNING: conduit not found."
 
 
@@ -103,7 +102,7 @@ def run(_input, output, schema):
 
 
 def translate_chunk(chunk, outputs, schema):
-    _chunk_id = re.search("_\d+", chunk)
+    _chunk_id = re.search(r"_\d+", chunk)
     chunk_id = _chunk_id[0]
     chunk_output = f"{outputs[0]}{chunk_id}{outputs[1]}"
     run(chunk, chunk_output, schema)
@@ -126,7 +125,7 @@ def process_args(_input, output, schema, do_chunks, n_processes):
 
 
 def generate_scalar_path_pairs(node, path=""):
-    """ Walk through the node finding the paths to the data and the data """
+    """Walk through the node finding the paths to the data and the data"""
     children = node.child_names()
     for child in children:
         if isinstance(node[child], conduit.Node):
@@ -139,7 +138,7 @@ def generate_scalar_path_pairs(node, path=""):
 
 
 def make_data_array_dict(d, node):
-    """ Pact a node to the end of the list in the dictionary with same name path """
+    """Pact a node to the end of the list in the dictionary with same name path"""
     for path, datum in generate_scalar_path_pairs(node):
         # patch for older versions of conduit
         datum = np.array(datum)
