@@ -1,6 +1,3 @@
-import argparse
-import sys
-
 import numpy as np
 from sklearn.ensemble import RandomForestRegressor
 
